#!/bin/bash

#    YAATOBS - yet another arm toolchain build script
# 
#    Copyright (C) 2019  Torsten Brischalle
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/

set -e

# Cortex M4 toolchain
export TOOLCHAIN_TYPE=cm4

# ARM9 toolchain
#export TOOLCHAIN_TYPE=arm9

export BINUTILS_VERSION=2.32
export GCC_VERSION=9.1.0
export NEWLIB_VERSION=3.1.0
export GDB_VERSION=8.3

export TOOLCHAIN_PREFIX=$(pwd)/install
export PATH="$TOOLCHAIN_PREFIX/bin:$PATH"

export WGET_OPT=--no-check-certificate

function config_cm4 {
  export TOOLCHAIN_TARGET="arm-cm4-eabi"
  export TOOLCHAIN_ARM_ARCH="armv7-m"
  export TOOLCHAIN_ARM_MODE="thumb"
  export TOOLCHAIN_ABI="aapcs"
  export TOOLCHAIN_FLOAT_ABI="hard"
  #export TOOLCHAIN_CPU="cortex-m4"
  export TOOLCHAIN_CPU=""
  export TOOLCHAIN_FPU="fpv4-sp-d16"
  export TOOLCHAIN_FULL_NAME="Cortex M4"
}

function config_arm9 {
  export TOOLCHAIN_TARGET="arm-none-eabi"
  export TOOLCHAIN_ARM_ARCH="armv5te"
  export TOOLCHAIN_ARM_MODE="arm"
  export TOOLCHAIN_ABI="aapcs"
  export TOOLCHAIN_FLOAT_ABI="soft"
  export TOOLCHAIN_CPU=""
  export TOOLCHAIN_FPU=""
  export TOOLCHAIN_FULL_NAME="ARM9"
}

case "$TOOLCHAIN_TYPE" in
"cm4")
  config_cm4
  ;;
"arm9")
  config_arm9
  ;;
*)
  echo "toolchain type must be cm4 (Cortex M4) or arm9"
  exit 1
  ;;
esac

install -d tmp
install -d sources

