#!/bin/bash

#    YAATOBS - yet another arm toolchain build script
# 
#    Copyright (C) 2019  Torsten Brischalle
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/

set -e

. ./00_settings.sh

GCC_FLAGS="--prefix=${TOOLCHAIN_PREFIX} --target=${TOOLCHAIN_TARGET} --enable-interwork --disable-werror \
           --disable-nls --disable-shared --enable-multilib \
           --disable-decimal-float --disable-threads \
           --disable-libmudflap --disable-libssp --disable-libgomp \
           --disable-libstdcxx-pch --with-newlib \
           --with-headers=../newlib-${NEWLIB_VERSION}/newlib/libc/include \
           --enable-languages=c \
           --with-system-zlib \
           --with-abi=${TOOLCHAIN_ABI} --with-arch=${TOOLCHAIN_ARM_ARCH} \
           --with-mode=${TOOLCHAIN_ARM_MODE} --with-float=${TOOLCHAIN_FLOAT_ABI}"

if [ -n "${TOOLCHAIN_CPU}" ]; then
  GCC_FLAGS+=" --with-cpu=${TOOLCHAIN_CPU}"
fi

if [ -n "${TOOLCHAIN_FPU}" ]; then
  GCC_FLAGS+=" --with-fpu=${TOOLCHAIN_FPU}"
fi
        
echo "*****************************************************"
echo "*** build gcc pass 1                              ***"
echo "*****************************************************"

cd tmp

rm -rf gcc-*-build
mkdir gcc-${GCC_VERSION}-build

if [ -d gcc-${GCC_VERSION} ]
then
  echo "gcc already extracted"
else
  if [ -e ../sources/gcc-${GCC_VERSION}.tar.gz ]
  then
    echo "gcc already downloaded"
  else
    echo "download gcc"
    wget ${WGET_OPT} -P ../sources https://ftpmirror.gnu.org/gcc/gcc-${GCC_VERSION}/gcc-${GCC_VERSION}.tar.gz
  fi

  echo "extract gcc"
  tar -xzf ../sources/gcc-${GCC_VERSION}.tar.gz
fi

cd gcc-${GCC_VERSION}-build
echo "configure gcc"
../gcc-${GCC_VERSION}/configure ${GCC_FLAGS}
echo "build gcc"
make all-gcc
make install-gcc

cd ../..

echo "*****************************************************"
echo "*** build gcc pass 1: DONE                        ***"
echo "*****************************************************"

